@@ -1,8 +1,8 @@
-from fluent import logger
+from fluent import sender
 
 class Event(object):
     def __init__(self, label, data, **kwargs):
         if not isinstance(data, dict) :
             raise Exception("data must be dict")
-        l = ('logger' in kwargs) and kwargs['logger'] or logger.get_global_logger()
+        l = ('sender' in kwargs) and kwargs['sender'] or sender.get_global_sender()
         l.emit(label, data)
